@@ -5,7 +5,9 @@
 #![cfg_attr(not(feature = "std"), no_std)]
 
 mod cid;
+pub mod codec;
 mod error;
+mod typed_cid;
 mod version;
 
 #[cfg(any(test, feature = "arb"))]
@@ -13,7 +15,11 @@ mod arb;
 
 pub use self::{
   cid::Cid as CidGeneric,
-  error::{Error, Result},
+  codec::Codec,
+  error::{
+    Error,
+    Result,
+  },
   version::Version,
 };
 
@@ -22,7 +28,10 @@ pub use sp_multihash;
 
 extern crate alloc;
 use bytecursor::ByteCursor;
-use unsigned_varint::{decode, encode as varint_encode};
+use unsigned_varint::{
+  decode,
+  encode as varint_encode,
+};
 
 /// Reader function from unsigned_varint
 pub fn varint_read_u64(r: &mut ByteCursor) -> Result<u64> {
@@ -45,4 +54,4 @@ pub fn varint_read_u64(r: &mut ByteCursor) -> Result<u64> {
 ///
 /// If you need a CID that is generic over its digest size, use [`CidGeneric`]
 /// instead.
-pub type Cid = CidGeneric<sp_multihash::U64>;
+pub type Cid = CidGeneric<64>;
